<?php
/**
 * OCDI support.
 *
 * @package magazine-elite
 */

/*Disable PT branding.*/
add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );

/**
 * OCDI files.
 *
 * @since 1.0.0
 *
 * @return array Files.
 */
function magazine_elite_import_files() {
    return array(
        array(
            'import_file_name'           =>  esc_html__( 'Theme Demo Content', 'magazine-elite' ),
            'import_file_url'            => 'https://demos.unfoldwp.com/magazine-elite/demo-content/magazine-elite.xml',
            'import_widget_file_url'     => 'https://demos.unfoldwp.com/magazine-elite/demo-content/magazine-elite.wie',
            'import_customizer_file_url' => 'https://demos.unfoldwp.com/magazine-elite/demo-content/magazine-elite.dat',
        ),
    );
}
add_filter( 'pt-ocdi/import_files', 'magazine_elite_import_files' );

/**
 * OCDI after import.
 *
 * @since 1.0.0
 */

function magazine_elite_after_import_setup() {
    // Assign front page and posts page (blog page).
    $front_page_id = null;
    $blog_page_id  = null;

    $front_page = get_page_by_title( 'Homepage' );

    if ( $front_page ) {
        if ( is_array( $front_page ) ) {
            $first_page = array_shift( $front_page );
            $front_page_id = $first_page->ID;
        } else {
            $front_page_id = $front_page->ID;
        }
    }

    $blog_page = get_page_by_title( 'Blog' );

    if ( $blog_page ) {
        if ( is_array( $blog_page ) ) {
            $first_page = array_shift( $blog_page );
            $blog_page_id = $first_page->ID;
        } else {
            $blog_page_id = $blog_page->ID;
        }
    }

    if ( $front_page_id && $blog_page_id ) {
        update_option( 'show_on_front', 'page' );
        update_option( 'page_on_front', $front_page_id );
        update_option( 'page_for_posts', $blog_page_id );
    }

    // Assign navigation menu locations.
    $menu_location_details = array(
        'topbar-menu' => 'top-navigation',
        'menu-1' => 'primary-navigation',
        'social-nav' => 'social-nav',
    );

    if ( ! empty( $menu_location_details ) ) {
        $navigation_settings = array();
        $current_navigation_menus = wp_get_nav_menus();
        if ( ! empty( $current_navigation_menus ) && ! is_wp_error( $current_navigation_menus ) ) {
            foreach ( $current_navigation_menus as $menu ) {
                foreach ( $menu_location_details as $location => $menu_slug ) {
                    if ( $menu->slug === $menu_slug ) {
                        $navigation_settings[ $location ] = $menu->term_id;
                    }
                }
            }
        }
        set_theme_mod( 'nav_menu_locations', $navigation_settings );
    }
}
add_action( 'pt-ocdi/after_import', 'magazine_elite_after_import_setup' );

/**
 * OCDI Setup Changes
 *
 * @since 1.0.7
 */
function magazine_elite_ocdi_setup( $default_settings ) {
    $default_settings['parent_slug'] = 'themes.php';
    $default_settings['page_title']  = esc_html__( 'Magazine Elite Demo Import' , 'magazine-elite' );
    $default_settings['menu_title']  = esc_html__( 'Import Demo Data' , 'magazine-elite' );
    $default_settings['capability']  = 'import';
    $default_settings['menu_slug']   = 'magazine-elite-demo-import';
 
    return $default_settings;
}
add_filter( 'ocdi/plugin_page_setup', 'magazine_elite_ocdi_setup' );

/**
 * OCDI Remove Title
 *
 * @since 1.0.7
 */
function magazine_elite_ocdi_title( $plugin_title ) {
    $plugin_title = "";
    return $plugin_title;
}
add_filter( 'ocdi/plugin_page_title', 'magazine_elite_ocdi_title' );

/**
 * OCDI Remove Intro text
 *
 * @since 1.0.7
 */
function magazine_elite_ocdi_intro( $plugin_intro_text ) {
    $plugin_intro_text = "";
    return $plugin_intro_text;
}
add_filter( 'ocdi/plugin_intro_text', 'magazine_elite_ocdi_intro' );